@@ -14,7 +14,7 @@ use Sub::Name ();
 package Kavorka;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.031';
+our $VERSION   = '0.032';
 
 our @ISA         = qw( Exporter::Tiny );
 our @EXPORT      = qw( fun method );
@@ -113,6 +113,11 @@ sub _exporter_fail
 	$implementation->can('parse')
 		or Carp::croak("No suitable implementation for keyword '$name'");
 	
+	# Workaround for RT#95786 which might be caused by a bug in the Perl
+	# interpreter.
+	require Sub::Defer;
+	Sub::Defer::undefer_all();
+	
 	# Kavorka::Multi (for example) needs to know what Kavorka keywords are
 	# currently in scope.
 	$^H{'Kavorka'} .= "$name=$implementation ";
